@@ -20,14 +20,22 @@
 This package allows to plot data or mathematical expressions inside python,
 using the gnuplot program, in the form of 2D or 3D plots.
 
+.. note:: If the package has been correctly installed, a small demo script can
+   be run from the system terminal by typing::
+
+   $ python -m gnuplot_manager.demo
+
+   or inside the python console by typing::
+
+   >>> from gnuplot_manager.demo import main
+   >>> main()
+
+   The demo will run without need of input and last about 35 seconds.
+
 Full documentation can be found at:
 
 https://github.com/pietromandracci/gnuplot_manager
 
-To run a test script type::
-
-$ python3 -m gnuplot_manager.test
-
 
 List of available functions
 ===========================
@@ -59,6 +67,7 @@ Plot data
 *plot_curves()*
     plot several curves at the same time
 
+
 Plot mathematical functions
 ---------------------------
 
@@ -122,7 +131,7 @@ Each plot window is an instance of the *_PlotWindow* class,
 which has several attributes:
 
 *self.window_number*:   
-    an integer number that identifies the plot window,                               
+    an integer number that identifies the plot window, [#window_number]_                               
     mainly used to generate unique names for the data files
 *self.gnuplot_process*: 
      gnuplot process (instance of *subprocess.Popen*)    
@@ -162,6 +171,10 @@ which has several attributes:
      if there was an error while opening the plot
      an error message is stored here
 
+.. [#window_number] Note that this number is *not* the index that identifies the
+   plot window inside the *window_list* variable: in fact the former is fixed,
+   while the latter may change when other windows are removed from the list.
+
 .. [#functions] Note that no check is made that function strings given to gnuplot 
    are correct. So even wrong ones (which therefore gnuplot has not plotted)
    are listed here.
@@ -192,8 +205,6 @@ of the *functions.py* module to perform their tasks:
    *functions.py* module, these methods are not intended to be called directly.
 """
 
-__version__ = '0.1.1'
-
 from .global_variables import *
 from .functions import *
 
